Sample - CKEditor

# CKEditor Sample

This sample shows how to use the dialog API to customize dialogs whithout changing the original editor code. The following customizations are being done::

1. Add dialog pages ("My Tab" in the Link dialog).
2. Remove a dialog tab ("Target" tab from the Link dialog).
3. Add dialog fields ("My Custom Field" into the Link dialog).
4. Remove dialog fields ("Link Type" and "Browser Server" the Link dialog).
5. Set default values for dialog fields (for the "URL" field in the Link dialog).
6. Create a custom dialog ("My Dialog" button).

<p>This is some <strong>sample text</strong>. You are using <a href="http://www.fckeditor.net/">CKEditor</a>.</p>